@@ -20,13 +20,15 @@
 """Config Module."""
 
 import copy
-import functools
 import logging
 import os
-from typing import Callable, MutableMapping, TypeVar
+import warnings
+from typing import MutableMapping
 from uuid import uuid4
 
-from ansiblelint.config import ansible_version
+from ansible_compat.ports import cache, cached_property
+from ansible_compat.runtime import Runtime
+from packaging.version import Version
 
 from molecule import api, interpolation, platforms, scenario, state, util
 from molecule.dependency import ansible_galaxy, shell
@@ -42,13 +44,15 @@ MOLECULE_FILE = "molecule.yml"
 MOLECULE_KEEP_STRING = "MOLECULE_"
 DEFAULT_DRIVER = "delegated"
 
-T = TypeVar("T")
 
-
-# see https://github.com/python/mypy/issues/5858
-def cache(func: Callable[..., T]) -> T:
-    """Decorate properties to cache them."""
-    return functools.lru_cache()(func)  # type: ignore
+@cache
+def ansible_version() -> Version:
+    """Retrieve Ansible version."""
+    warnings.warn(
+        "molecule.config.ansible_version is deprecated, will be removed in the future.",
+        category=DeprecationWarning,
+    )
+    return Runtime().version
 
 
 # https://stackoverflow.com/questions/16017397/injecting-function-call-after-init-with-decorator  # noqa
@@ -102,6 +106,7 @@ class Config(object, metaclass=NewInitCaller):
         self._action = None
         self._run_uuid = str(uuid4())
         self.project_directory = os.getenv("MOLECULE_PROJECT_DIRECTORY", os.getcwd())
+        self.runtime = Runtime(isolated=True)
 
     def after_init(self):
         self.config = self._reget_config()
@@ -115,7 +120,7 @@ class Config(object, metaclass=NewInitCaller):
     def ansible_collections_path(self):
         """Return collection path variable for current version of Ansible."""
         # https://github.com/ansible/ansible/pull/70007
-        if ansible_version() >= ansible_version("2.10.0.dev0"):
+        if self.runtime.version >= Version("2.10.0.dev0"):
             return "ANSIBLE_COLLECTIONS_PATH"
         else:
             return "ANSIBLE_COLLECTIONS_PATHS"
@@ -156,8 +161,7 @@ class Config(object, metaclass=NewInitCaller):
     def molecule_directory(self):
         return molecule_directory(self.project_directory)
 
-    @property  # type: ignore  # see https://github.com/python/mypy/issues/1362
-    @util.lru_cache()
+    @cached_property
     def dependency(self):
         dependency_name = self.config["dependency"]["name"]
         if dependency_name == "galaxy":
@@ -165,8 +169,7 @@ class Config(object, metaclass=NewInitCaller):
         elif dependency_name == "shell":
             return shell.Shell(self)
 
-    @property  # type: ignore
-    @util.lru_cache()
+    @cached_property
     def driver(self):
         driver_name = self._get_driver_name()
         driver = None
@@ -196,36 +199,30 @@ class Config(object, metaclass=NewInitCaller):
             "MOLECULE_VERIFIER_TEST_DIRECTORY": self.verifier.directory,
         }
 
-    @property  # type: ignore
-    @util.lru_cache()
+    @cached_property
     def lint(self):
         lint_name = self.config.get("lint", None)
         return lint_name
 
-    @property  # type: ignore
-    @util.lru_cache()
+    @cached_property
     def platforms(self):
         return platforms.Platforms(self, parallelize_platforms=self.is_parallel)
 
-    @property  # type: ignore
-    @cache
+    @cached_property
     def provisioner(self):
         provisioner_name = self.config["provisioner"]["name"]
         if provisioner_name == "ansible":
             return ansible.Ansible(self)
 
-    @property  # type: ignore
-    @util.lru_cache()
+    @cached_property
     def scenario(self):
         return scenario.Scenario(self)
 
-    @property  # type: ignore
-    @util.lru_cache()
+    @cached_property
     def state(self):
         return state.State(self)
 
-    @property  # type: ignore
-    @util.lru_cache()
+    @cached_property
     def verifier(self):
         return api.verifiers(self).get(self.config["verifier"]["name"], None)
 
@@ -282,8 +279,8 @@ class Config(object, metaclass=NewInitCaller):
         environment variables.
 
         1. Loads Molecule defaults.
-        2. Loads a base config (if provided) and merges ontop of defaults.
-        3. Loads the scenario's ``molecule file`` and merges ontop of previous
+        2. Loads a base config (if provided) and merges on top of defaults.
+        3. Loads the scenario's ``molecule file`` and merges on top of previous
            merge.
 
         :return: dict
@@ -433,12 +430,12 @@ class Config(object, metaclass=NewInitCaller):
             util.sysexit_with_message(msg)
 
 
-def molecule_directory(path):
+def molecule_directory(path: str) -> str:
     """Return directory of the current scenario."""
     return os.path.join(path, MOLECULE_DIRECTORY)
 
 
-def molecule_file(path):
+def molecule_file(path: str) -> str:
     """Return file path of current scenario."""
     return os.path.join(path, MOLECULE_FILE)
 
