@@ -23,12 +23,15 @@ from __future__ import print_function
 import binascii
 import io
 import os
+import warnings
 
 import pytest
 
 from molecule import util
+from molecule.api import IncompatibleMoleculeRuntimeWarning, MoleculeRuntimeWarning
 from molecule.console import console
 from molecule.constants import MOLECULE_HEADER
+from molecule.test.conftest import get_molecule_file, molecule_directory
 from molecule.text import strip_ansi_escape
 
 
@@ -92,6 +95,21 @@ def test_sysexit_with_message(patched_logger_critical):
     patched_logger_critical.assert_called_once_with("foo")
 
 
+def test_sysexit_with_warns(patched_logger_critical, patched_logger_warning):
+    with pytest.raises(SystemExit) as e:
+
+        with warnings.catch_warnings(record=True) as warns:
+            warnings.filterwarnings("default", category=MoleculeRuntimeWarning)
+            warnings.warn("xxx", category=IncompatibleMoleculeRuntimeWarning)
+
+        util.sysexit_with_message("foo", warns=warns)
+
+    assert 1 == e.value.code
+
+    patched_logger_critical.assert_called_once_with("foo")
+    patched_logger_warning.assert_called_once_with("xxx")
+
+
 def test_sysexit_with_message_and_custom_code(patched_logger_critical):
     with pytest.raises(SystemExit) as e:
         util.sysexit_with_message("foo", 2)
@@ -164,14 +182,14 @@ def test_run_command_with_debug_handles_no_env(mocker, patched_print_debug):
 
 def test_os_walk(temp_dir):
     scenarios = ["scenario1", "scenario2", "scenario3"]
-    molecule_directory = pytest.helpers.molecule_directory()
+    mol_dir = molecule_directory()
     for scenario in scenarios:
-        scenario_directory = os.path.join(molecule_directory, scenario)
-        molecule_file = pytest.helpers.get_molecule_file(scenario_directory)
+        scenario_directory = os.path.join(mol_dir, scenario)
+        molecule_file = get_molecule_file(scenario_directory)
         os.makedirs(scenario_directory)
         util.write_file(molecule_file, "")
 
-    result = [f for f in util.os_walk(molecule_directory, "molecule.yml")]
+    result = [f for f in util.os_walk(mol_dir, "molecule.yml")]
     assert 3 == len(result)
 
 
